==> haskell-blaze-textual-0.2.3.1-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-4Rsde2SsUsfE3XLw5fl8lG
key:                  blaze-textual-0.2.3.1-4Rsde2SsUsfE3XLw5fl8lG
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  8ce954efffb026930b202fcf21fa55da
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-4Rsde2SsUsfE3XLw5fl8lG
depends:
    base-4.17.2.1 blaze-builder-0.4.3-6IYx8eSaGHUJnwII0Up24j
    bytestring-0.11.5.3 ghc-prim-0.9.1 integer-gmp-1.1
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2
    vector-0.13.2.0-GTax7SJDHXyLP8P6Lzhygl

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-textual-0.2.3.1-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-textual
version:              0.2.3.1
visibility:           public
id:                   blaze-textual-0.2.3.1-1F6silE748TEW90Te9Bp0l
key:                  blaze-textual-0.2.3.1-1F6silE748TEW90Te9Bp0l
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:           Andrey Prokopenko <persiantiger@yandex.ru>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/swamp-agr/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/swamp-agr/blaze-textual#readme>

category:             Text
abi:                  4b33be241388f1ad921145bcb3b3ebc6
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/blaze-textual-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.3.1-1F6silE748TEW90Te9Bp0l
depends:
    base-4.17.2.1 blaze-builder-0.4.3-4yy7EUiUNtIb1TX5lPJzq
    bytestring-0.11.5.3 ghc-prim-0.9.1 integer-gmp-1.1
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh text-2.0.2
    vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
